@@ -1,4 +1,6 @@
 // Globally available exports
+pub mod edcryptor;
+pub mod error;
+pub mod flags;
 pub mod header;
 pub mod reg_entry;
-pub mod types;
