@@ -1,8 +1,4 @@
-use crate::{
-	global::{
-		types::{Flags},
-	},
-};
+use crate::global::flags::Flags;
 
 use std::{
 	convert::TryInto,
@@ -10,15 +6,21 @@ use std::{
 	fmt,
 };
 use ed25519_dalek as esdalek;
+use super::error::InternalError;
 
+/// Stand-alone meta-data from an archive entry(Leaf). This can be parsed without reading data about the leaf.
 #[derive(Debug, Clone)]
 pub struct RegistryEntry {
+	/// The flags extracted from the archive entry and parsed into a struct
 	pub flags: Flags,
+	/// The content version of the extracted archive entry
 	pub content_version: u8,
+	/// The signature of the extracted archive entry
 	pub signature: Option<esdalek::Signature>,
-
-	pub(crate) location: u64,
-	pub(crate) offset: u64,
+	/// The location of the file in the archive, as bytes from the beginning of the file
+	pub location: u64,
+	/// The offset|size of the `Leaf`, in bytes. This does not always correspond to the actual size of the file when read from the archive! ie when compressed
+	pub offset: u64,
 }
 
 impl RegistryEntry {
@@ -35,28 +37,41 @@ impl RegistryEntry {
 			offset: 0,
 		}
 	}
+	/// Given a read handle, will proceed to read and parse bytes into a `RegistryEntry` struct. (de-serialization)
 	pub(crate) fn from_handle<T: Read + Seek>(
-		mut handle: T, read_sig: bool,
-	) -> anyhow::Result<(Self, String)> {
+		mut handle: T,
+	) -> Result<(Self, String), InternalError> {
 		let mut buffer = [0; RegistryEntry::MIN_SIZE];
 		handle.read_exact(&mut buffer)?;
 
 		// Construct entry
 		let mut entry = RegistryEntry::empty();
-		entry.flags = Flags::from_bits(u16::from_le_bytes(buffer[0..2].try_into()?));
+		entry.flags = Flags::from_bits(u16::from_le_bytes([buffer[0], buffer[1]]));
 		entry.content_version = buffer[2];
 
-		entry.location = u64::from_le_bytes(buffer[3..11].try_into()?);
-		entry.offset = u64::from_le_bytes(buffer[11..19].try_into()?);
+		entry.location = u64::from_le_bytes([
+			buffer[3], buffer[4], buffer[5], buffer[6], buffer[7], buffer[8], buffer[9], buffer[10],
+		]);
 
-		let id_length = u16::from_le_bytes(buffer[19..RegistryEntry::MIN_SIZE].try_into()?);
+		entry.offset = u64::from_le_bytes([
+			buffer[11], buffer[12], buffer[13], buffer[14], buffer[15], buffer[16], buffer[17],
+			buffer[18],
+		]);
+
+		let id_length = u16::from_le_bytes([buffer[19], buffer[20]]);
 
 		/* The data after this is dynamically sized, therefore *MUST* be read conditionally */
 		// Only produce a flag from data that is signed
-		if read_sig {
-			let mut buffer = [0u8; crate::SIGNATURE_LENGTH];
-			handle.read_exact(&mut buffer)?;
-			entry.signature = Some(buffer.try_into()?);
+		if entry.flags.contains(Flags::SIGNED_FLAG) {
+			let mut sig_bytes = [0u8; crate::SIGNATURE_LENGTH];
+			handle.read_exact(&mut sig_bytes)?;
+
+			let sig: esdalek::Signature = match sig_bytes.try_into() {
+				Ok(sig) => sig,
+				Err(err) => return Err(InternalError::ParseError(err.to_string())),
+			};
+
+			entry.signature = Some(sig);
 		};
 
 		// Construct ID
@@ -66,6 +81,7 @@ impl RegistryEntry {
 		Ok((entry, id))
 	}
 
+	/// Serializes a `RegistryEntry` struct into an array of bytes
 	pub(crate) fn bytes(&self, id_length: &u16) -> Vec<u8> {
 		let mut buffer = Vec::new();
 		buffer.extend_from_slice(&self.flags.bits().to_le_bytes());
