@@ -1,7 +1,8 @@
 use ed25519_dalek as esdalek;
 use rand::rngs::OsRng;
-use std::io::Read;
-use anyhow;
+use std::{io::Read};
+
+use crate::global::error::InternalError;
 
 /// Use this function to easily generate a [Keypair](https://docs.rs/ed25519-dalek/1.0.1/ed25519_dalek/struct.Keypair.html) using `OsRng`
 #[inline(always)]
@@ -9,9 +10,12 @@ pub fn gen_keypair() -> esdalek::Keypair {
 	esdalek::Keypair::generate(&mut OsRng)
 }
 
-// Use this to read and parse a `Keypair` from a `io::Read` handle
-pub(crate) fn read_keypair<R: Read>(mut handle: R) -> anyhow::Result<esdalek::Keypair> {
+/// Use this to read and parse a `Keypair` from a `io::Read` handle
+pub fn read_keypair<R: Read>(mut handle: R) -> Result<esdalek::Keypair, InternalError> {
 	let mut keypair_bytes = [0; crate::KEYPAIR_LENGTH];
 	handle.read_exact(&mut keypair_bytes)?;
-	Ok(esdalek::Keypair::from_bytes(&keypair_bytes)?)
+	Ok(match esdalek::Keypair::from_bytes(&keypair_bytes) {
+		Ok(kep) => kep,
+		Err(err) => return Err(InternalError::ParseError(err.to_string())),
+	})
 }
