@@ -1,16 +1,16 @@
-use crate::global::types::Flags;
+use crate::global::{error::InternalError, flags::Flags};
 use std::io;
 use ed25519_dalek as esdalek;
 
-/// Alows for the customization of valid `vach` archives during their construction.
+/// Allows for the customization of valid `vach` archives during their construction.
 /// Such as custom `MAGIC`, custom `Header` flags and signing by providing a keypair.
 #[derive(Debug)]
 pub struct BuilderConfig {
-	/// Stores a custom magic sequence that identifies an source as a valid archive source.
+	/// Used to write a unique magic sequence into the write target.
 	pub magic: [u8; crate::MAGIC_LENGTH],
-	/// Flags that are found in the `Header` section of an archive source
+	/// Flags to be written into the `Header` section of the write target.
 	pub flags: Flags,
-	/// An optional keypair. If a key is provided, then the archive source will be signed.
+	/// An optional keypair. If a key is provided, then the write target will have signatures for tamper verification.
 	pub keypair: Option<esdalek::Keypair>,
 }
 
@@ -43,7 +43,7 @@ impl BuilderConfig {
 
 	// Keypair helpers
 	/// Parses and stores a keypair from a source.
-	pub fn load_keypair<T: io::Read>(&mut self, handle: T) -> anyhow::Result<()> {
+	pub fn load_keypair<T: io::Read>(&mut self, handle: T) -> Result<(), InternalError> {
 		self.keypair = Some(crate::utils::read_keypair(handle)?);
 		Ok(())
 	}
